@@ -24,8 +24,7 @@
 #include <solid/devices/ifaces/devicemanager.h>
 #include <solid/deviceinterface.h>
 
-#include <QtCore/QVariant>
-#include <QtCore/QStringList>
+#include <QStringList>
 
 namespace Solid
 {
@@ -43,16 +42,16 @@ public:
     HalManager(QObject *parent);
     virtual ~HalManager();
 
-    QString udiPrefix() const Q_DECL_OVERRIDE;
-    QSet<Solid::DeviceInterface::Type> supportedInterfaces() const Q_DECL_OVERRIDE;
+    QString udiPrefix() const override;
+    QSet<Solid::DeviceInterface::Type> supportedInterfaces() const override;
 
     bool deviceExists(const QString &udi);
-    QStringList allDevices() Q_DECL_OVERRIDE;
+    QStringList allDevices() override;
 
     virtual QStringList devicesFromQuery(const QString &parentUdi,
-                                         Solid::DeviceInterface::Type type) Q_DECL_OVERRIDE;
+                                         Solid::DeviceInterface::Type type) override;
 
-    QObject *createDevice(const QString &udi) Q_DECL_OVERRIDE;
+    QObject *createDevice(const QString &udi) override;
 
 private Q_SLOTS:
     void slotDeviceAdded(const QString &udi);
