@@ -39,7 +39,7 @@ public:
     bool isPlugged() const;
 
 private Q_SLOTS:
-    void doStart() Q_DECL_OVERRIDE;
+    void doStart() override;
 
 /**
  * We have to re-declare the signal because
